#ifndef SETTINGSDLG_H
#define SETTINGSDLG_H

#include <QDialog>
#include "stundenplan.h"

namespace Ui {
    class SettingsDlg;
}

class SettingsDlg : public QDialog
{
    Q_OBJECT

public:
    explicit SettingsDlg(Stundenplan *p,QWidget *parent = 0);
    ~SettingsDlg();
    int updateintervall;

private slots:
    void on_pushButton_clicked();

    void on_pushButton_2_clicked();

    void on_horizontalSlider_valueChanged(int value);

private:
    Ui::SettingsDlg *ui;
    Stundenplan *sp;

};

#endif // SETTINGSDLG_H
